#
# spec file for package sunpinyin
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sunpinyin
Version:        2.0.99.2
Release:        2.5
Summary:        A Statistical Language Model Based Chinese Input Method
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/sunpinyin/sunpinyin
Source:         https://github.com/sunpinyin/sunpinyin/archive/v3.0.0-rc2/%{name}-3.0.0-rc2.tar.gz
# https://sourceforge.net/projects/open-gram
Source1:        http://jaist.dl.sourceforge.net/project/open-gram/lm_sc.3gm.arpa-20140820.tar.bz2
Source2:        http://jaist.dl.sourceforge.net/project/open-gram/dict.utf8-20131214.tar.bz2
Source3:        sunpinyin-dictgen-local.mk.in
# PATCH-FIX-OPENSUSE marguerite@opensuse.org do not download online
Patch1:         no-download.patch
# PATCH-FIX-UPSTREAM bmwiedemann@opensuse.org make build reproducible
# Patch2:         reproducible.patch
# PATCH-FIx-UPSTREAM sunpinyin-scons-on-py3.patch dimstar@opensuse.org -- Fix build with scons using python3 as interpreter
# Patch3:         sunpinyin-scons-on-py3.patch
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  scons
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(sqlite3)
Provides:       locale(ibus:zh_CN;zh_SG)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Sunpinyin is a statistical language model based Chinese input method engine. to
model the Chinese language, it use a backoff bigram and trigram language model.

%package -n lib%{name}3
Summary:        Libraries for Sunpinyin
Group:          System/Libraries
Requires:       %{name}-data >= %{version}

%description -n lib%{name}3
Sunpinyin is a statistical language model based Chinese input method engine. to
model the Chinese language, it use a backoff bigram and trigram language model.

%package data
Summary:        Data files for Sunpinyin
Group:          System/I18n/Chinese

%description data
Sunpinyin is a statistical language model based Chinese input method engine. to
model the Chinese language, it use a backoff bigram and trigram language model.

This package provides data files needed by it.

%package tools
Summary:        Dictionary tools for Sunpinyin
Group:          System/I18n/Chinese

%description tools
Sunpinyin is a statistical language model based Chinese input method engine. to
model the Chinese language, it use a backoff bigram and trigram language model.

This package provides dictionary tools needed by it.

%package devel
Summary:        Development Files for Sunpinyin
Group:          Development/Libraries/C and C++
Requires:       lib%{name}3 = %{version}
Requires:       sunpinyin-tools = %{version}
Provides:       lib%{name}-devel = %{version}
Obsoletes:      lib%{name}-devel < %{version}

%description devel
Sunpinyin is a statistical language model based Chinese input method engine. to
model the Chinese language, it use a backoff bigram and trigram language model.

This package provides development headers for it.

%prep
%autosetup -p1 -n %{name}-3.0.0-rc2
cp -r %{SOURCE1} .
cp -r %{SOURCE2} .
cp -r %{SOURCE3} src

%build
export CXXFLAGS+="%{optflags}"
scons --prefix=%{_prefix}

%install
scons --prefix=%{_prefix} \
      --libdir=%{_libdir} \
      --install-sandbox=%{buildroot} \
      install

# make dicts
src/sunpinyin-dictgen-local
mkdir -p %{buildroot}%{_datadir}/%{name}
install -m 0644 lm_sc.t3g %{buildroot}%{_datadir}/%{name}
install -m 0644 pydict_sc.bin %{buildroot}%{_datadir}/%{name}

# fix doc
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%post -n lib%{name}3 -p /sbin/ldconfig

%postun -n lib%{name}3 -p /sbin/ldconfig

%files -n lib%{name}3
%defattr(-,root,root)
%doc AUTHORS NEWS README.md TODO
%license COPYING LGPL.LICENSE OPENSOLARIS.LICENSE
%{_libdir}/lib%{name}.so.*

%files data
%defattr(-,root,root)
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/lm_sc.t3g
%{_datadir}/%{name}/pydict_sc.bin

%files tools
%defattr(-,root,root)
%{_bindir}/genpyt
%{_bindir}/getwordfreq
%{_bindir}/idngram_merge
%{_bindir}/ids2ngram
%{_bindir}/mmseg
%{_bindir}/slmbuild
%{_bindir}/slminfo
%{_bindir}/slmpack
%{_bindir}/slmprune
%{_bindir}/slmseg
%{_bindir}/slmthread
%{_bindir}/%{name}-dictgen
%{_bindir}/tslmendian
%{_bindir}/tslminfo
%{_mandir}/man1/genpyt.1.gz
%{_mandir}/man1/getwordfreq.1.gz
%{_mandir}/man1/idngram_merge.1.gz
%{_mandir}/man1/ids2ngram.1.gz
%{_mandir}/man1/mmseg.1.gz
%{_mandir}/man1/slmbuild.1.gz
%{_mandir}/man1/slminfo.1.gz
%{_mandir}/man1/slmpack.1.gz
%{_mandir}/man1/slmprune.1.gz
%{_mandir}/man1/slmseg.1.gz
%{_mandir}/man1/slmthread.1.gz
%{_mandir}/man1/tslmendian.1.gz
%{_mandir}/man1/tslminfo.1.gz

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}-2.0/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}-2.0.pc

%changelog
* Mon Dec  5 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on Python 2.
* Mon Nov  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.0.0-RC2(2.0.99.2)
  * work around multiple-monitors setup
  * Portability fix for NetBSD iconv
  * make setup window compatible with python3
  * pytrie_gen.cpp: work around iconv() segfault with musl
  * Add support for m68k architecture
  * Fix issue#89
  * wrapper: xim: Make SConstruct python3-compatible
  * Update xib user interface file to recent version
  * Update xcode project, force to sign dependecies
  * Use PRODUCT_BUNDLE_IDENTIFIER as identifier
  * Remove "Localize and Compile XIBs" phase
- Drop sunpinyin-scons-on-py3.patch and reproducible.patch. Merge by upstream.
* Tue Jun 19 2018 schwab@suse.de
- sunpinyin-aarch64.patch: Remove obsolete patch
* Thu Nov 23 2017 dimstar@opensuse.org
- Add sunpinyin-scons-on-py3.patch: Fix build with scons using
  python3 as interpreter.
* Tue Sep 12 2017 hillwood@opensuse.org
- Update to 3.0.0rc1
  * fix the pod2man invocations: 63ef4bb
  * Add support for DESTDIR: 9232a1e
  * add travis-ci integration: f01c99e
  * fixed the FTBFS on gcc6: 844ad0f
  * handle AArch64 architecture: 96b3342
  * hacks to support ve/ue: cf3fe3d
  * shuangpin related fixes: 33091ba, 4c1acf5
  * Support 'ng', 'hm' and 'rua': 3bbbf8f
  * Use lve/nve instead of lue/nue: 4f9745c
  * fix invalid 'yai' case: d6e9f34
  * fixed the userdict saving issue: 7d8b8b1
  * expose userdict to public, easier to import user dict.: a4bfe22
  * fix crashes, merge the duplicate sentences: fa7ec5f
  * optimized the add operation from O(n) to O(log n): 08f5da8
  * fixed crash in preeditstring when partial commit with empty pinyin: b728af3
  * add Python plugin support. refact uiobjects: CCandidateList and CPreeditString: 57370b8
- Fix doc filelist.
- Remove useless %%post and %%postun.
* Tue May  2 2017 bwiedemann@suse.com
- Add reproducible.patch to make build fully reproducible
* Sun Mar  6 2016 i@marguerite.su
- update to version 2.0.4+git20160225.844ad0f:
  + Fixed SunPinyinLookupTable::cursor_up()
  + slm/thread: be more tolerant when looking up a float
  + SLM-train.mk: publish SLM*_TEXT_FILE instead of
    TSLM*_TEXT_FILE.
- libsunpinyin3 should requires sunpinyin-data, or the
  input method can't be used
* Sun Aug 23 2015 i@marguerite.su
- update to version 2.0.4+git20150706.cf18102:
  + fix pod2man invocations
- drop sunpinyin-gcc47.patch, forgot to delete the file
- add patch: no-download.patch, don't download dicts online
* Sat Mar 23 2013 schwab@suse.de
- sunpinyin-aarch64.patch: get endianess for aarch64
* Sun Jun 24 2012 i@marguerite.su
- fix fedora builds.
* Mon Jun  4 2012 i@marguerite.su
- update version to 2.0.4git, to be compatible with latest fcitx.
- drop gcc47 patch. upstream fixed.
* Sat Mar 17 2012 zaitor@opensuse.org
- Add sunpinyin-gcc47.patch: Fix build with gcc 4.7.
* Thu Jan 26 2012 i@marguerite.su
- merge changelog
* Wed Jan 25 2012 i@marguerite.su
- initial package 2.0.4
* Sat Sep 10 2011 stecue@gmail.com
- Updated to 2.0.3.99. Thanks to csslayer!
* Mon Aug  1 2011 tiwai@suse.de
- Rename libsunpinyin3-devel to libsunpinyin-devel
- Add explicitly dependency from devel sub-package
- Clean up spec file
* Tue May 31 2011 stecue@gmail.com 2.0.3
- Check the license for open-gram.
- bz2ed all sources.
* Mon Feb 21 2011 hillwood<hillwood@linuxfans.org>
- First build 2.0.3 for suse and Fedora.
